PgEvent class

Available extensions
Annotations
  • @freezed

Constructors

PgEvent.getInvoiceStatus({required PgStatusRequest request})
const
factory
const
factory

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

map<TResult extends Object?>({required TResult getLink(_GetLink value), required TResult getInvoiceStatus(_GetInvoiceStatus value)}) → TResult

Available on PgEvent, provided by the PgEventPatterns extension

A switch-like method, using callbacks.
mapOrNull<TResult extends Object?>({TResult? getLink(_GetLink value)?, TResult? getInvoiceStatus(_GetInvoiceStatus value)?}) → TResult?

Available on PgEvent, provided by the PgEventPatterns extension

A variant of map that fallback to returning null.
maybeMap<TResult extends Object?>({TResult getLink(_GetLink value)?, TResult getInvoiceStatus(_GetInvoiceStatus value)?, required TResult orElse()}) → TResult

Available on PgEvent, provided by the PgEventPatterns extension

A variant of map that fallback to returning orElse.
maybeWhen<TResult extends Object?>({TResult getLink(String terminalId, String mid, double amount, String name, int mobile, String txnType, String paymentMode, String currency, String udf4, String udf5, String udf6, String udf7, String udf8, String udf9, String udf10, String callbackUrl, String ru, String email, String merchantTransactionId, String transactionDate, String productType, String txnNote)?, TResult getInvoiceStatus(PgStatusRequest request)?, required TResult orElse()}) → TResult

Available on PgEvent, provided by the PgEventPatterns extension

A variant of when that fallback to an orElse callback.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited
when<TResult extends Object?>({required TResult getLink(String terminalId, String mid, double amount, String name, int mobile, String txnType, String paymentMode, String currency, String udf4, String udf5, String udf6, String udf7, String udf8, String udf9, String udf10, String callbackUrl, String ru, String email, String merchantTransactionId, String transactionDate, String productType, String txnNote), required TResult getInvoiceStatus(PgStatusRequest request)}) → TResult

Available on PgEvent, provided by the PgEventPatterns extension

A switch-like method, using callbacks.
whenOrNull<TResult extends Object?>({TResult? getLink(String terminalId, String mid, double amount, String name, int mobile, String txnType, String paymentMode, String currency, String udf4, String udf5, String udf6, String udf7, String udf8, String udf9, String udf10, String callbackUrl, String ru, String email, String merchantTransactionId, String transactionDate, String productType, String txnNote)?, TResult? getInvoiceStatus(PgStatusRequest request)?}) → TResult?

Available on PgEvent, provided by the PgEventPatterns extension

A variant of when that fallback to returning null

Operators

operator ==(Object other) bool
The equality operator.
inherited