PgState class abstract

Available extensions
Annotations
  • @freezed

Constructors

PgState({required PgRepo repo, @Default.new(PgStatus.initial) PgStatus status, @Default.new('') String error, PgLinkResponse? response, PgInvoiceResponse? pgInvoiceResponse, PgInvoiceResponse? pgInvoiceResponseError})
const
factory

Properties

copyWith → $PgStateCopyWith<PgState>
Create a copy of PgState with the given fields replaced by the non-null parameter values.
no setterinherited
error String
no setterinherited
hashCode int
The hash code for this object.
no setterinherited
pgInvoiceResponse PgInvoiceResponse?
no setterinherited
pgInvoiceResponseError PgInvoiceResponse?
no setterinherited
repo PgRepo
no setterinherited
response PgLinkResponse?
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
status PgStatus
no setterinherited

Methods

map<TResult extends Object?>(TResult $default(_PgState value)) → TResult

Available on PgState, provided by the PgStatePatterns extension

A switch-like method, using callbacks.
mapOrNull<TResult extends Object?>(TResult? $default(_PgState value)?) → TResult?

Available on PgState, provided by the PgStatePatterns extension

A variant of map that fallback to returning null.
maybeMap<TResult extends Object?>(TResult $default(_PgState value)?, {required TResult orElse()}) → TResult

Available on PgState, provided by the PgStatePatterns extension

A variant of map that fallback to returning orElse.
maybeWhen<TResult extends Object?>(TResult $default(PgRepo repo, PgStatus status, String error, PgLinkResponse? response, PgInvoiceResponse? pgInvoiceResponse, PgInvoiceResponse? pgInvoiceResponseError)?, {required TResult orElse()}) → TResult

Available on PgState, provided by the PgStatePatterns extension

A variant of when that fallback to an orElse callback.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited
when<TResult extends Object?>(TResult $default(PgRepo repo, PgStatus status, String error, PgLinkResponse? response, PgInvoiceResponse? pgInvoiceResponse, PgInvoiceResponse? pgInvoiceResponseError)) → TResult

Available on PgState, provided by the PgStatePatterns extension

A switch-like method, using callbacks.
whenOrNull<TResult extends Object?>(TResult? $default(PgRepo repo, PgStatus status, String error, PgLinkResponse? response, PgInvoiceResponse? pgInvoiceResponse, PgInvoiceResponse? pgInvoiceResponseError)?) → TResult?

Available on PgState, provided by the PgStatePatterns extension

A variant of when that fallback to returning null

Operators

operator ==(Object other) bool
The equality operator.
inherited