toString method

  1. @override
String toString()
inherited

A string representation of this object.

Some classes have a default textual representation, often paired with a static parse function (like int.parse). These classes will provide the textual representation as their string representation.

Other classes have no meaningful textual representation that a program will care about. Such classes will typically override toString to provide useful information when inspecting the object, mainly for debugging or logging.

Implementation

@override
String toString() {
  return 'PgRequest(amount: $amount, currency: $currency, merchantTransactionId: $merchantTransactionId, mid: $mid, paymentMode: $paymentMode, productType: $productType, terminalId: $terminalId, transactionDate: $transactionDate, txnNote: $txnNote, txnType: $txnType, udf1: $udf1, udf2: $udf2, udf3: $udf3, udf4: $udf4, udf5: $udf5, udf6: $udf6, udf7: $udf7, udf8: $udf8, udf9: $udf9, udf10: $udf10, callbackUrl: $callbackUrl, ru: $ru)';
}