PgStatusRequest class abstract

Available extensions
Annotations
  • @freezed

Constructors

PgStatusRequest({required String terminalId, required String mid, required String paymentId, @Default.new('') String refrenceNo, @Default.new('') String status})
factory
PgStatusRequest.fromJson(Map<String, Object?> json)
factory

Properties

copyWith → $PgStatusRequestCopyWith<PgStatusRequest>
Create a copy of PgStatusRequest with the given fields replaced by the non-null parameter values.
no setterinherited
hashCode int
The hash code for this object.
no setterinherited
mid String
no setterinherited
paymentId String
no setterinherited
refrenceNo String
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
status String
no setterinherited
terminalId String
no setterinherited

Methods

map<TResult extends Object?>(TResult $default(_PgStatusRequest value)) → TResult

Available on PgStatusRequest, provided by the PgStatusRequestPatterns extension

A switch-like method, using callbacks.
mapOrNull<TResult extends Object?>(TResult? $default(_PgStatusRequest value)?) → TResult?

Available on PgStatusRequest, provided by the PgStatusRequestPatterns extension

A variant of map that fallback to returning null.
maybeMap<TResult extends Object?>(TResult $default(_PgStatusRequest value)?, {required TResult orElse()}) → TResult

Available on PgStatusRequest, provided by the PgStatusRequestPatterns extension

A variant of map that fallback to returning orElse.
maybeWhen<TResult extends Object?>(TResult $default(String terminalId, String mid, String paymentId, String refrenceNo, String status)?, {required TResult orElse()}) → TResult

Available on PgStatusRequest, provided by the PgStatusRequestPatterns extension

A variant of when that fallback to an orElse callback.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
Serializes this PgStatusRequest to a JSON map.
inherited
toString() String
A string representation of this object.
inherited
when<TResult extends Object?>(TResult $default(String terminalId, String mid, String paymentId, String refrenceNo, String status)) → TResult

Available on PgStatusRequest, provided by the PgStatusRequestPatterns extension

A switch-like method, using callbacks.
whenOrNull<TResult extends Object?>(TResult? $default(String terminalId, String mid, String paymentId, String refrenceNo, String status)?) → TResult?

Available on PgStatusRequest, provided by the PgStatusRequestPatterns extension

A variant of when that fallback to returning null

Operators

operator ==(Object other) bool
The equality operator.
inherited