PGKit class

Inheritance

Constructors

PGKit({Key? key, required String terminalId, required String mid, required double amount, required String name, required String email, required int mobile, required String txnType, required String paymentMode, required String? currency, required Widget child, required dynamic onError(PgInvoiceResponse error), required dynamic onSuccess(PgInvoiceResponse success), required String pgKey, required String pgIv, required bool test, String? ru, required String udf4, required String udf5, required String udf6, required String udf7, required String udf8, required String udf9, required String udf10, required String callbackUrl, required String? merchantTransactionId, required String? transactionDate, String? txnNote = '', required String? productType})
const

Properties

amount double
final
callbackUrl String
final
child Widget
final
currency String?
final
email String
final
hashCode int
The hash code for this object.
no setterinherited
key Key?
Controls how one widget replaces another widget in the tree.
finalinherited
merchantTransactionId String?
final
mid String
final
mobile int
final
name String
final
onError → dynamic Function(PgInvoiceResponse error)
final
onSuccess → dynamic Function(PgInvoiceResponse success)
final
paymentMode String
final
pgIv String
final
pgKey String
final
productType String?
final
ru String?
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
terminalId String
final
test bool
final
transactionDate String?
final
txnNote String?
final
txnType String
final
udf10 String
final
udf4 String
final
udf5 String
final
udf6 String
final
udf7 String
final
udf8 String
final
udf9 String
final

Methods

build(BuildContext context) Widget
Describes the part of the user interface represented by this widget.
override
createElement() StatelessElement
Creates a StatelessElement to manage this widget's location in the tree.
inherited
debugDescribeChildren() List<DiagnosticsNode>
Returns a list of DiagnosticsNode objects describing this node's children.
inherited
debugFillProperties(DiagnosticPropertiesBuilder properties) → void
Add additional properties associated with the node.
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toDiagnosticsNode({String? name, DiagnosticsTreeStyle? style}) DiagnosticsNode
Returns a debug representation of the object that is used by debugging tools and by DiagnosticsNode.toStringDeep.
inherited
toString({DiagnosticLevel minLevel = DiagnosticLevel.info}) String
A string representation of this object.
inherited
toStringDeep({String prefixLineOne = '', String? prefixOtherLines, DiagnosticLevel minLevel = DiagnosticLevel.debug, int wrapWidth = 65}) String
Returns a string representation of this node and its descendants.
inherited
toStringShallow({String joiner = ', ', DiagnosticLevel minLevel = DiagnosticLevel.debug}) String
Returns a one-line detailed description of the object.
inherited
toStringShort() String
A short, textual description of this widget.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited