PgLinkResponse class abstract
- Available extensions
- Annotations
-
- @freezed
Constructors
- PgLinkResponse({required String paymentId, required String paymentUrl, required String? qrIntent, required String? qr})
-
factory
-
PgLinkResponse.fromJson(Map<
String, Object?> json) -
factory
Properties
-
copyWith
→ $PgLinkResponseCopyWith<
PgLinkResponse> -
Create a copy of PgLinkResponse
with the given fields replaced by the non-null parameter values.
no setterinherited
- hashCode → int
-
The hash code for this object.
no setterinherited
- paymentId → String
-
no setterinherited
- paymentUrl → String
-
no setterinherited
- qr → String?
-
no setterinherited
- qrIntent → String?
-
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
map<
TResult extends Object?> (TResult $default(_PgLinkResponse value)) → TResult -
Available on PgLinkResponse, provided by the PgLinkResponsePatterns extension
Aswitch-like method, using callbacks. -
mapOrNull<
TResult extends Object?> (TResult? $default(_PgLinkResponse value)?) → TResult? -
Available on PgLinkResponse, provided by the PgLinkResponsePatterns extension
A variant ofmapthat fallback to returningnull. -
maybeMap<
TResult extends Object?> (TResult $default(_PgLinkResponse value)?, {required TResult orElse()}) → TResult -
Available on PgLinkResponse, provided by the PgLinkResponsePatterns extension
A variant ofmapthat fallback to returningorElse. -
maybeWhen<
TResult extends Object?> (TResult $default(String paymentId, String paymentUrl, String? qrIntent, String? qr)?, {required TResult orElse()}) → TResult -
Available on PgLinkResponse, provided by the PgLinkResponsePatterns extension
A variant ofwhenthat fallback to anorElsecallback. -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
Serializes this PgLinkResponse to a JSON map.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
-
when<
TResult extends Object?> (TResult $default(String paymentId, String paymentUrl, String? qrIntent, String? qr)) → TResult -
Available on PgLinkResponse, provided by the PgLinkResponsePatterns extension
Aswitch-like method, using callbacks. -
whenOrNull<
TResult extends Object?> (TResult? $default(String paymentId, String paymentUrl, String? qrIntent, String? qr)?) → TResult? -
Available on PgLinkResponse, provided by the PgLinkResponsePatterns extension
A variant ofwhenthat fallback to returningnull
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited